package com.alibaba.edas.unit.test;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.Socket;

import org.junit.Test;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import com.alibaba.edas.unit.consumer.UnitTestXMLConsumer;
import com.alibaba.edas.unit.service.UnitTestService;
import com.alibaba.edas.unit.service.impl.UnitTestServiceImpl;
import com.taobao.hsf.lightapi.ServiceFactory;

/**
 * 通过LightApi方式进行单元化测试（提供Bean方式和XML方式进行单元测试）
 * 
 * @author Jason
 *
 */
public class LightApiTest {

	// 这里设置Pandora地址，参数是sar包所在目录，如这里我的sar包地址是/Users/Jason/Work/AliSoft/PandoraSar/DevSar/taobao-hsf.sar，则只取前面的地址即可
	private static final ServiceFactory factory = ServiceFactory
			.getInstanceWithPath("/Users/Jason/Work/AliSoft/PandoraSar/DevSar");

	/**
	 * 1.通过设置Bean方式进行服务发布
	 * 
	 * @throws Exception
	 */
	@Test
	public void testBeanPubOrSubService() throws Exception {
		// 进行服务发布（若有发布者，无需再这里写）
		factory.provider("helloProvider")// 参数是一个标识，初始化后，下次只需调用provider("helloProvider")即可拿出对应服务
				.service("com.alibaba.edas.unit.service.UnitTestService")// 接口全类名
				.version("1.0.0")// 版本号
				.group("light")// 组别
				.impl(new UnitTestServiceImpl())// 对应的服务实现
				.publish();// 发布服务，至少要调用service()和version()才可以发布服务

		// 进行服务消费
		factory.consumer("helloConsumer")// 参数是一个标识，初始化后，下次只需调用consumer("helloConsumer")即可直接拿出对应服务
				.service("com.alibaba.edas.unit.service.UnitTestService")// 接口全类名
				.version("1.0.0")// 版本号
				.group("light")// 组别
				.subscribe();

		factory.consumer("helloConsumer").sync();// 同步等待地址推送，最多6秒。
		UnitTestService log4jService = (UnitTestService) factory.consumer("helloConsumer").subscribe();// 用ID取出对应服务，subscribe()方法返回对应的接口
		// 调用服务方法
		System.out.println("bean -> msg rec success:-"+log4jService.print());
	}
	
	/**
	 *2.测试通过XML方式进行加载提供者和消费者进行单元测试
	 */
	@Test
	public void testXMLPubOrSubService(){
		//xml方式加载服务提供者
		new ClassPathXmlApplicationContext("hsf-provider-beans.xml");
		//xml方式加载服务消费者
		ClassPathXmlApplicationContext consumerContext=new ClassPathXmlApplicationContext("hsf-consumer-beans.xml");
		//获取bean
		UnitTestXMLConsumer unitTestXMLConsumer=(UnitTestXMLConsumer) consumerContext.getBean("unitTestConsumer");
		//服务调用 
		unitTestXMLConsumer.testUnitProvider();
	}
	
	@Test
	public void test(){
		Socket s = new Socket();
		try {
			s.bind(new InetSocketAddress("192.178.20.12", 1990));
			s.close();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		System.out.println("********");
	}

}
